@@ -1,7 +1,7 @@
 from itertools import product
 
-from pkrcomponents.rank import Rank
-from pkrcomponents.suit import Suit
+from pkrcomponents.cards.rank import Rank
+from pkrcomponents.cards.suit import Suit
 
 
 class CardMeta(type):
@@ -15,3 +15,6 @@ class CardMeta(type):
 
     def __iter__(cls):
         return iter(cls.all_cards)
+
+    def __len__(cls):
+        return len(cls.all_cards)
