@@ -1,6 +1,5 @@
-from itertools import product, combinations
-from pkrcomponents.card import Card
-from pkrcomponents.shape import Shape
+from itertools import combinations
+from pkrcomponents.cards.card import Card
 
 
 class ComboMeta(type):
@@ -17,3 +16,6 @@ class ComboMeta(type):
 
     def __iter__(cls):
         return iter(cls.all_combos)
+
+    def __len__(cls):
+        return len(cls.all_combos)
